
### this script finds subtypes with respect to Parkers centroids, using an modified gene centering methods, taking ER proportion into account.  

arg = commandArgs()

### read GEX data:
cat("1) Reading file: ", arg[2], "\n")
xpr.test = read.table( file = paste("dataInput", arg[2], sep="/"), sep="\t")
xpr.test = data.matrix(xpr.test)
n= ncol(xpr.test)
  
### Read parkers centroids: 
load("dataInput/ParkerData.Rdata")
if( sum(rownames(xpr.test) == colnames(ParkerData$centroids)) != 50 ){  # need to be equal to 0. Then all the PAM50 genes are match in our data and Parkers data.
      exit()
}

#################################################### find and store data: 
mainDir = getwd() 
setwd(paste(  mainDir , "dataOutput" , arg[1], sep="/") ) 

########################################################
########################################################
######## classify the ER +/- patients according to expression of the ESR1 gene.
exp_ESR1 = xpr.test[ rownames(xpr.test) == "ESR1" , ]
d=density(exp_ESR1)
ERcutoff = d[[1]][  which(diff(sign(diff(d[[2]]))) != 0)[2]+1 ]

pdf("distribution_ESR1.pdf")
    plot(d,main=paste("ESR1 with ER cut off at ", round(ERcutoff, 2), sep=""), xlab="", ylim=c(0,0.4))
    hist(exp_ESR1, 50, freq=FALSE, add=T)
    abline(v=ERcutoff, col="red")                   #check that the red line (the ER cut off) is at the bottom between the two tops
dev.off()

ERstatus_ESR1 = rep(NA, times=n); names(ERstatus_ESR1) = colnames(xpr.test)
ERstatus_ESR1[ exp_ESR1 < ERcutoff ] = 0
ERstatus_ESR1[ exp_ESR1 >= ERcutoff ] = 1
table(ERstatus_ESR1)
# 0  1    macro 
#18 76 

# 0  1    bulk
#16 78 

ERinfo = cbind(ERstatus_ESR1, exp_ESR1, ERcutoff )
save(ERinfo, file="ESR1info.Rdata")


########################################################
########################################################
######## find the centering value per gene in our dataset (while taking into account the ER proportion)
theERstat = ERstatus_ESR1  #fill in the ER status (either from the section above, or from previous findings)
center.test = rep(NA,50)
for (i in 1:50) {
    center.test[i]    = ParkerData$alpha * mean(xpr.test[i,theERstat==0 & !is.na(theERstat)]) + (1-ParkerData$alpha) * mean(xpr.test[ i, theERstat==1 & !is.na(theERstat) ])
}

######## center the test data
xpr.test.correct    = matrix(0, nrow(xpr.test), ncol(xpr.test))
rownames(xpr.test.correct)=rownames(xpr.test); colnames(xpr.test.correct)=colnames(xpr.test);
for (i in 1:ncol(xpr.test)) {
    xpr.test.correct[,i] = xpr.test[,i] - center.test + ParkerData$center.train
}

########################################################
########################################################
## select the 46 genes (removing BIRC5, CCNB1, GRB7, and MYBL2). 
remove4Genes = c("BIRC5", "CCNB1", "GRB7", "MYBL2")

colnames(ParkerData$centroids)[ which( colnames(ParkerData$centroids) %in% remove4Genes ) ]
colnames(ParkerData$centroids)[ which(! colnames(ParkerData$centroids) %in% remove4Genes ) ]

geneIndex46 = which(! colnames(ParkerData$centroids) %in% remove4Genes )

########################################################
######## Perform subtyping
Cor                = matrix(0, ncol(xpr.test.correct), 5)
colnames(Cor)      = subtypeNames
rownames(Cor)      = colnames(xpr.test.correct)
for (i in 1:ncol(xpr.test.correct)) {
    for (j in 1:5) {
        Cor[i,j] = cor(xpr.test.correct[ geneIndex46 ,i], ParkerData$centroids[j, geneIndex46 ], method="pearson")
    }
}
subtype_withNormal         = colnames(Cor)[apply(Cor,1,function(x)match(max(x),x))]
subtype_withoutNormal      = colnames(Cor)[apply(Cor[,-5],1,function(x)match(max(x),x))]

subtype_ERcor_info = data.frame(Cor)
subtype_ERcor_info$subtype_withNormal = subtype_withNormal 
subtype_ERcor_info$subtype_withoutNormal = subtype_withoutNormal 

head(subtype_ERcor_info)

cat(names(table(subtype_ERcor_info$subtype_withNormal)), "\n")
cat(table(subtype_ERcor_info$subtype_withNormal), "\n")

save(subtype_ERcor_info, file="SubtypeInfo_ERcorMethod.Rdata")




######### scatter plot : centered expression VS centroids
pdf("ScatterPlot_expressionPerSample_EachCentroid.pdf", width=7, height=7*1.7)
for (i in 1:ncol(xpr.test.correct)) {
par(mfrow=c(3,2))
    for (j in 1:5) {
        plot(xpr.test.correct[,i], ParkerData$centroids[j,], main=paste("Cor= ", round(Cor[i,j],2) , sep=""), xlab=paste("Expression sample ",colnames(xpr.test.correct)[i],sep=""), ylab=paste("Centroid subtype ",rownames(ParkerData$centroids)[j] ,sep=""), type="n")
        text(xpr.test.correct[,i], ParkerData$centroids[j,], labels=colnames(ParkerData$centroids))
    }
}
dev.off()

setwd(mainDir)
