
mainDir = getwd() 
setwd(paste( mainDir, "dataOutput", sep="/") )

#########################################################################
#########################################################################
#### This file prints Figure 2 and 3
#########################################################################
#########################################################################

library(ggplot2)
library(ggrepel)
library(vipor)
library(cowplot)
library(ggpubr)
library(gridExtra)
library(grid)
library(lattice)

colSubtype = c("Basal-like" = "red", "HER2-enriched"="pink", "Luminal A"="darkblue", "Luminal B"="skyblue", "Normal-like"="#00BA42", na.value="grey")
colROR = c("#F37B59", "#AFA100", "#00BA42")
colRORcont = topo.colors(100)
colRORcont = terrain.colors(100)

shapeP = 16
shapeFFPE = 16
shapeFF = 17

#### gglplot function to write selected text (here: R^2) within a plot: 
lm_eqn <- function(df, x, y){
  m <- lm(y ~ x, df);
  eq <- substitute(~~italic(r)^2~"="~r2, 
                   list(a = format(unname(coef(m)[1]), digits = 2),
                        b = format(unname(coef(m)[2]), digits = 2),
                        r2 = format(summary(m)$r.squared, digits = 3)))
  as.character(as.expression(eq));
}

#########################################################################
#########################################################################
#########################################################################
load("annotFile_n94.Rdata", verbos=T)
dim(annotFile_94)
annotFile_94$subtype.nCounter  = annotFile_94$subtype_ERmod_nCounter$subtype_withNormal
annotFile_94$subtype.RNAseq    = annotFile_94$subtype_ERmod_RNAseq$subtype_withNormal

#########################################################################
#########################################################################
#########################################################################
#### Figure 2: Comparing ROR and subtypes information
#########################################################################
#########################################################################
#########################################################################

## comparing ROR
fig2B <- ggplot(annotFile_94, aes(ROR, RORtot_Cont_nCounter)) + 
  geom_abline(intercept = 0, slope = 1, color="black", linetype="dashed", size=0.3)+
  geom_point(aes(color = Subtype), shape=shapeP ) +
  scale_colour_manual(values=colSubtype) + 
  geom_text(x = 15, y = 95, label = lm_eqn(annotFile_94, annotFile_94$ROR, annotFile_94$RORtot_Cont_nCounter), parse = TRUE) + 
  labs(x = "ROR-Prosigna" ) +
  labs(y = "ROR-macro") +
  ylim(0,100)+
  xlim(0,100)+
  theme_bw()+
  theme(plot.title = element_text(hjust = 0.5, face='bold'), legend.position = "none") 
fig2B

fig2C <- ggplot(annotFile_94, aes(ROR, RORtot_Cont_RNAseq)) + 
  geom_abline(intercept = 0, slope = 1, color="black", linetype="dashed", size=0.3)+
  geom_point(aes(color = Subtype), shape=shapeP) +
  scale_colour_manual(values=colSubtype) + 
  labs(x = "ROR-Prosigna" ) +
  labs(y = "ROR-bulk") +
  ylim(0,100)+
  xlim(0,100)+
  theme_bw()+
  theme(plot.title = element_text(hjust = 0.5, face='bold'), legend.position = "none")+
  geom_text(x = 15, y = 95, label = lm_eqn(annotFile_94, annotFile_94$ROR, annotFile_94$RORtot_Cont_RNAseq), parse = TRUE)
fig2C

fig2D <- ggplot(annotFile_94, aes(RORtot_Cont_nCounter, RORtot_Cont_RNAseq)) + 
  geom_abline(intercept = 0, slope = 1, color="black", linetype="dashed", size=0.3)+
  geom_point(aes(color = Subtype), shape=shapeP) +
  scale_colour_manual(values=colSubtype) + 
  labs(x = "ROR-macro" ) +
  labs(y = "ROR-bulk") +
  ylim(0,100)+
  xlim(0,100)+
  theme_bw()+
  theme(plot.title = element_text(hjust = 0.5, face='bold'), legend.position = "none")+
  geom_text(x = 15, y = 95, label = lm_eqn(annotFile_94,annotFile_94$RORtot_Cont_nCounter, annotFile_94$RORtot_Cont_RNAseq ), parse = TRUE)
fig2D

########## Categorical
## only include ER+ and HER2- (in the clnical setting) and those with node-degree=0
table(annotFile_94$LN.Status)  # choose    "0"
table(annotFile_94$ER)         # not    "neg" 
table(annotFile_94$HER2.IHC)   # not    "pos" og "pos(3+)"
table(annotFile_94$HER2.IHC, annotFile_94$HER2.FISH)

annotFile_selected = annotFile_94[ annotFile_94$LN.Status == "pN0" , ]
annotFile_selected = annotFile_selected[ annotFile_selected$ER != "neg" , ]
annotFile_selected = annotFile_selected[ annotFile_selected$HER2.IHC != "pos", ] 
annotFile_selected = annotFile_selected[ annotFile_selected$HER2.IHC != "pos(3+)", ] 
dim(annotFile_selected) #54 

fig2Dcat <- ggplot(annotFile_selected, aes(RORtot_Cont_nCounter, RORtot_Cont_RNAseq)) + 
  geom_point(aes(color = Risk.Group), shape=shapeP) +
  scale_colour_manual(values=colROR) + 
  geom_hline(aes(yintercept = CutOffHigh), color='darkgrey') + 
  geom_hline(aes(yintercept = CutOffLow), color='darkgrey') + 
  geom_vline(aes(xintercept = CutOffHigh), color='darkgrey') + 
  geom_vline(aes(xintercept = CutOffLow), color='darkgrey') + 
  ylim(0,100)+
  xlim(0,100)+
  labs(x = "ROR-macro") +
  labs(y = "ROR-bulk")+
  theme_bw()+
  theme(plot.title = element_text(hjust = 0.5, face='bold'), legend.position = "none") +
  geom_text(x = 15, y = 95, label = lm_eqn(annotFile_selected, annotFile_selected$RORtot_Cont_nCounter, annotFile_selected$RORtot_Cont_RNAseq), parse = TRUE)+
  geom_text(x = 15, y = 85, label = "~(italic(n) ~ \"=\" ~ \"54\")", parse = TRUE)
fig2Dcat

table(annotFile_selected$RORtot_Cat_nCounter, annotFile_selected$RORtot_Cat_RNAseq)
#tot=13+7+21+13
#13/54

#########################################################################
#########################################################################
### structure the data for the correlation plot (2A and 3A)
n=nrow(annotFile_94)

map2color<-function(x,pal,limits=NULL){
  if(is.null(limits)) limits=range(x)
  pal[findInterval(x,seq(limits[1],limits[2],length.out=length(pal)+1), all.inside=TRUE)]
}

#data we need: 
distMatrise            = annotFile_94$subtype_ERmod_nCounter[,1:5]
dist2ProsignaSubtype   = rep(NA, times=n)
for(i in 1:n){  dist2ProsignaSubtype[i] = distMatrise[i, as.numeric(as.factor(annotFile_94$Subtype))[i] ] }

distMatriseBulk        = annotFile_94$subtype_ERmod_RNAseq[,1:5]
dist2ProsignaSubtype_bulk   = rep(NA, times=n)
for(i in 1:n){  dist2ProsignaSubtype_bulk[i] = distMatriseBulk[i, as.numeric(as.factor(annotFile_94$Subtype))[i] ] }


theData = data.frame(
  Subtype.Prosigna       = annotFile_94$Subtype,
  ROR.Prosigna            = annotFile_94$ROR,
  #
  Subtype.macro          = names(colSubtype)[apply( distMatrise,     1, function(x){which(x==sort(x, decreasing=T)[1])})],
  highestCor             = apply( distMatrise, 1, function(x){sort(x, decreasing=T)[1]}),
  dist2ProsignaSubtype   = dist2ProsignaSubtype,
  #
  Subtype.bulk                = names(colSubtype)[apply( distMatriseBulk, 1, function(x){which(x==sort(x, decreasing=T)[1])})],
  highestCor.bulk             = apply( distMatriseBulk, 1, function(x){sort(x, decreasing=T)[1]}),
  dist2ProsignaSubtype.bulk   = dist2ProsignaSubtype_bulk)

#########################################################################
######### building Fig 2A:
pdf("Fig2.pdf", height=9, width=7)
par(mfrow=c(2,1), mar=c(2, 6, 2, 2))
thePlotOrder = order(theData$Subtype.Prosigna, theData$dist2ProsignaSubtype)
distMatrise_order = distMatrise[thePlotOrder, ]
theData_order = theData[thePlotOrder,]

# distance/correlation curves (theData$distMatrise)
plot( x=1:n, y=distMatrise_order[,1], col="red", xlim=c(0,n), ylim=c(-1,1.7), pch=16, xlab="", ylab="", las=2, xaxt="n" , yaxt="n", main="") 
rect(par("usr")[1], par("usr")[3], par("usr")[2], par("usr")[4], col = "white")
for(i in 1:5){
  points( x=1:n, y=distMatrise_order[,i], col=colSubtype[i], pch=16)
}

#help lines: 
abline(h=1.4)
abline(h=c(1,-1), col="lightgrey")
abline(h=c(-1.5,-3.5), col="lightgrey")
abline(v=cumsum(table(theData_order$Subtype.Prosigna))[1:3]+0.5, col="lightgrey")
abline(h=0, lwd=3, lty=2, col="lightgrey")

#draw the y-axis text: (ylab="Correlation to subtype-macro")
axis(side=2, at=c(-1,-0.5,0,0.5,1), labels=c(-1,-0.5,0,0.5,1), las=2  )
axis(side=2, at=c(-1,-0.5,0,0.5,1)-2.5, labels=c(-1,-0.5,0,0.5,1), las=2  )
thesubtypesPos = c(-1.25,1.2, 1.6)
axis(side=2, at=thesubtypesPos, labels=c("", "Macro", "Prosigna"), las=2  )

#points( x=1:n, y=rep(thesubtypesPos[1], times=n), col=colSubtype[theData_order$Subtype.bulk], pch=16)
points( x=1:n, y=rep(thesubtypesPos[2], times=n), col=colSubtype[as.numeric(theData_order$Subtype.macro)], pch=16)
points( x=1:n, y=rep(thesubtypesPos[3], times=n), col=colSubtype[as.numeric(theData_order$Subtype.Prosigna)], pch=16)

#lines: 
theIndex=(as.character(theData_order$Subtype.macro) != as.character(theData_order$Subtype.Prosigna))
theIndex = which(theIndex)
for(i in 1:length(theIndex)){#make small horizontal lines between the "miss-classified" subtypes: 
  lines(x=c(theIndex[i],theIndex[i]), y=c( theData_order$highestCor[theIndex[i]] , theData_order$dist2ProsignaSubtype[theIndex[i]] ) )
}

### combining with 2B - 2E: 
vp <- viewport(height=unit(.5, "npc"), width=unit(1, "npc"), 
                           just=c("left","top"),  y=0.5, x=0)
print(plot_grid(fig2B, fig2C, fig2D, fig2Dcat, labels = c('B', 'C', 'D', 'E'),  ncol = 2), vp=vp)

dev.off() 


#########################################################################
#########################################################################
#########################################################################
#### Figure 3 : Characterizing Proliferation, normal infiltration :
#########################################################################
#########################################################################
#########################################################################

Fig3B <- ggplot(annotFile_94, aes( prolifDist18_nCounter, prolifDist18_RNAseq ) ) + 
  geom_abline(intercept = 0, slope = 1, color="black", linetype="dashed", size=0.3)+
  geom_point(aes(color = subtype.RNAseq)) +
  scale_colour_manual(values=colSubtype) + 
  labs(x = "Proliferation in macro") +
  labs(y = "Proliferation in bulk") +
  geom_text(x=-1, y = 2, label = lm_eqn(annotFile_94, annotFile_94$prolifDist18_nCounter, annotFile_94$prolifDist18_RNAseq), parse = TRUE)+
  theme_bw()+
  theme(plot.title = element_text(hjust = 0.5, face='bold'), legend.position = "none" ) 
Fig3B  

Fig3C <- ggplot(annotFile_94, aes(RORtot_Cont_nCounter, RORtot_Cont_RNAseq)) + 
  geom_abline(intercept = 0, slope = 1, color="black", linetype="dashed", size=0.3)+
  geom_point(aes(color = subtype.RNAseq)) +
  scale_colour_manual(values=colSubtype) + 
  ylim(0,100)+
  xlim(0,100)+
  labs(x = "ROR-Macro") +
  labs(y = "ROR-Bulk") +
  geom_text(x = 15, y = 95, label = lm_eqn(annotFile_94, annotFile_94$RORtot_Cont_nCounter, annotFile_94$RORtot_Cont_RNAseq), parse = TRUE)+
  theme_bw()+
  theme(plot.title = element_text(hjust = 0.5, face='bold'), legend.position = "none" ) 
Fig3C

###########################################
## Path scores (Tumor% and normal epithilium)
Fig3D <- ggplot(annotFile_94, aes( subtype.RNAseq, tumorContent_IBCandDCIS ) ) + 
  geom_boxplot(aes(fill = subtype.RNAseq))+
  scale_fill_manual(values=colSubtype) + 
  labs(x = "") +
  labs(y = "Tumor %") +
  scale_x_discrete(guide = guide_axis(n.dodge = 2)) +
  theme_bw()+
  theme(plot.title = element_text(hjust = 0.5, face='bold'), legend.position = "none" ) 
Fig3D  

Fig3E <- ggplot(annotFile_94, aes( subtype.RNAseq  , Normal.breast.epithelium ) ) + 
  geom_boxplot(aes(fill = subtype.RNAseq))+
  scale_fill_manual(values=colSubtype) + 
  labs(x = "") +
  labs(y = "Normal epithelium %") +
  scale_x_discrete(guide = guide_axis(n.dodge = 2)) +
  theme_bw()+
  theme(plot.title = element_text(hjust = 0.5, face='bold'), legend.position = "none" ) 
Fig3E  


###########################################
pdf("Fig3.pdf", height=9, width=7)
par(mfrow=c(2,1), mar=c(2, 6, 2, 2))
thePlotOrder = order(theData$Subtype.Prosigna, theData$dist2ProsignaSubtype.bulk)
distMatrise_bulk_order = distMatriseBulk[thePlotOrder, ]
theData_order = theData[thePlotOrder,]

# distance/correlation curves (theData$distMatrise)
plot( x=1:n, y=distMatriseBulk[,1], col="red", xlim=c(0,n), ylim=c(-1,1.7), pch=16, xlab="", ylab="", las=2, xaxt="n" , yaxt="n", main="") 
rect(par("usr")[1], par("usr")[3], par("usr")[2], par("usr")[4], col = "white")
for(i in 1:5){
  points( x=1:n, y=distMatrise_bulk_order[,i], col=colSubtype[i], pch=16)
}

#help lines: 
abline(h=1.4)
abline(h=c(1,-1), col="lightgrey")
abline(h=c(-1.5,-3.5), col="lightgrey")
abline(v=cumsum(table(theData_order$Subtype.Prosigna))[1:3]+0.5, col="lightgrey")
abline(h=0, lwd=3, lty=2, col="lightgrey")

#draw the y-axis text: (ylab="Correlation to subtype-macro")
axis(side=2, at=c(-1,-0.5,0,0.5,1), labels=c(-1,-0.5,0,0.5,1), las=2  )
axis(side=2, at=c(-1,-0.5,0,0.5,1)-2.5, labels=c(-1,-0.5,0,0.5,1), las=2  )
thesubtypesPos = c(1.2, 1.6)
axis(side=2, at=thesubtypesPos, labels=c("Bulk", "Prosigna"), las=2  )

points( x=1:n, y=rep(thesubtypesPos[1], times=n), col=colSubtype[as.numeric(theData_order$Subtype.bulk)], pch=16)
points( x=1:n, y=rep(thesubtypesPos[2], times=n), col=colSubtype[as.numeric(theData_order$Subtype.Prosigna)], pch=16)

#lines: 
theIndex=(as.character(theData_order$Subtype.bulk) != as.character(theData_order$Subtype.Prosigna))
theIndex = which(theIndex)
for(i in 1:length(theIndex)){#make small horisontal lines between the "miss-classified" subtypes: 
  lines(x=c(theIndex[i],theIndex[i]), y=c( theData_order$highestCor.bulk[theIndex[i]] , theData_order$dist2ProsignaSubtype.bulk[theIndex[i]] ) )
}


#########################
vp <- viewport(height=unit(.5, "npc"), width=unit(1, "npc"), 
               just=c("left","top"),  y=0.5, x=0)
print(plot_grid(Fig3B, Fig3C, Fig3D, Fig3E, labels = c('B', 'C', 'D', 'E'),  ncol = 2), vp=vp)

dev.off() 





#########################################################################
#########################################################################
#########################################################################
### legends: 
#########################################################################
#########################################################################
#########################################################################

ledengS <- ggplot(annotFile_94, aes(RORtot_Cont_nCounter, RORtot_Cont_RNAseq)) + 
  geom_point(aes(color = subtype.RNAseq), shape=19, size=4) +
  scale_colour_manual(values=colSubtype, name = "Subtypes") +
  xlim(0,100)+
  theme(legend.justification = "left")+
  theme_bw()
ledengS

ledengR <- ggplot(annotFile_94, aes(RORtot_Cont_nCounter, RORtot_Cont_RNAseq)) + 
  geom_point(aes(color = Risk.Group), shape=19, size=4) +
  scale_colour_manual(values=colROR, name = "ROR") + 
  xlim(0,100)+
  theme(legend.justification = "left")+
  theme_bw()
ledengR


pdf("legends.pdf", height=6, width=6)
plot_grid(
  ledengR,
  ledengS,
  align = "v",  ncol = 1) #
grid.arrange(ledengS,ledengR, ncol=1)
dev.off() 



#########################################################################
#########################################################################
#########################################################################
#### The tables 
#########################################################################
#########################################################################
#########################################################################

##### Main table 1: the miss match between macro and bulk: within the 54 cases
the13cases = annotFile_selected[ annotFile_selected$RORtot_Cat_nCounter != annotFile_selected$RORtot_Cat_RNAseq , c("SampleID", "ROR", "Risk.Group", "RORtot_Cont_nCounter", "RORtot_Cat_nCounter", "RORtot_Cont_RNAseq", "RORtot_Cat_RNAseq") ]
the13cases = the13cases[ order(the13cases$RORtot_Cont_nCounter - the13cases$RORtot_Cont_RNAseq), ]
the13cases$RORtot_Cont_nCounter = round( the13cases$RORtot_Cont_nCounter , 2)
the13cases$RORtot_Cont_RNAseq = round( the13cases$RORtot_Cont_RNAseq , 2)
#write.table(the13cases, file="updatedMainTab1.txt", sep="\t", row.names=FALSE, dec = ".", quote=FALSE)

summary(the13cases$RORtot_Cont_nCounter - the13cases$RORtot_Cont_RNAseq)
#      Min.  1st Qu.   Median     Mean  3rd Qu.     Max. 
# -25.6900 -19.0800  -9.1300   0.3331  21.4300  44.0600 
summary(abs(the13cases$RORtot_Cont_nCounter - the13cases$RORtot_Cont_RNAseq))
#  Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
# 4.28   11.31   20.67   20.58   25.69   44.06 


#    SampleID ROR   Risk.Group RORtot_Cont_nCounter RORtot_Cat_nCounter RORtot_Cont_RNAseq RORtot_Cat_RNAseq           The Previouse versjon - Disagreemen.Macro.Bulk
# 34    BC-34  39     Low risk             37.87209            Low risk           63.55957         High risk                                                     TRUE
# 30    BC-30  32     Low risk             24.90066            Low risk           47.30431      Intermediate                                                     TRUE
# 35    BC-35  57 Intermediate             54.86166        Intermediate           75.52506         High risk                                                     TRUE
# 20    BC-20  39     Low risk             34.69188            Low risk           53.76872      Intermediate                                                     TRUE
# 85    BC-85  30     Low risk             25.65196            Low risk           42.82960      Intermediate                                                       FALSE
# 72    BC-72  41 Intermediate             34.09893            Low risk           45.40571      Intermediate                                                     TRUE
# 17    BC-17  47 Intermediate             39.94303            Low risk           49.07024      Intermediate                                                       FALSE
# 88    BC-88  57 Intermediate             53.92631        Intermediate           60.06393         High risk                                                     TRUE
# 23    BC-23  45 Intermediate             42.70586        Intermediate           38.43055          Low risk                                                       FALSE
# 58    BC-58  46 Intermediate             50.42479        Intermediate           28.98759          Low risk                                                     TRUE
# 47    BC-47  60 Intermediate             56.65689        Intermediate           26.85146          Low risk                                                     TRUE
# 38    BC-38  55 Intermediate             52.69401        Intermediate           16.35417          Low risk                                                     TRUE
# 70    BC-70  64    High risk             62.18194           High risk           18.12439          Low risk                                                     TRUE

theBC25cases = annotFile_selected[ annotFile_selected$SampleID == "BC-25" , c("SampleID", "ROR", "Risk.Group", "RORtot_Cont_nCounter", "RORtot_Cat_nCounter", "RORtot_Cont_RNAseq", "RORtot_Cat_RNAseq") ]
theBC25cases

# main table 2
table(annotFile_94$subtype.nCounter, annotFile_94$subtype.RNAseq)


#########################################################################
#########################################################################
##### supplementary table 1 ## all clinical info
clinicalTable = annotFile_94[, c("SampleID", 
                                 "Subtype", "ROR", "Risk.Group" , 
                                 "Tumor.size", "LN.Status", "ER", "PGR", "HER2.IHC", "HER2.FISH",
                                 "Invasive.tumor.component" , "Insitu","Stromal","Lymphocyt","Adipose.tissue","Normal.breast.epithelium", 
                                 "subtype.nCounter", "RORtot_Cont_nCounter", "RORtot_Cat_nCounter", 
                                 "subtype.RNAseq", "RORtot_Cont_RNAseq", "RORtot_Cat_RNAseq")]
missMatch = annotFile_94$RORtot_Cat_nCounter != annotFile_94$RORtot_Cat_RNAseq
clinicalTable$missMatch = missMatch
clinicalTable$RORtot_Cont_nCounter = round(clinicalTable$RORtot_Cont_nCounter, 2)
clinicalTable$RORtot_Cont_RNAseq = round(clinicalTable$RORtot_Cont_RNAseq, 2)
#write.table(clinicalTable, file="SupplTab1.txt", sep="\t", row.names=FALSE, dec = ".")

#write.table(clinicalTable, file="/Volumes/PRIVATE USB/EMIT_tonje/ROR paper/tilSubmition/makingTheInputDataForPaperAndGithub/annotFile_withRecodingOfIDs/updatedSupplTab1.txt", sep="\t", row.names=FALSE, dec = ".", quote=FALSE)


#########################################################################
#########################################################################
##### supplementary table 2
table(annotFile_94$subtype.nCounter, annotFile_94$Subtype)

##### supplementary table 3
## the 14 cases with discordant subtypes from Supplementary Table 2
tmp = annotFile_94[annotFile_94$subtype.nCounter != annotFile_94$Subtype,c("SampleID", "ROR", "Subtype", "subtype.nCounter", "subtype_ERmod_nCounter")]
tmp = cbind(tmp[,1:4],round(tmp$subtype_ERmod_nCounter[,1:5],2) )
#write.table(tmp, file="SupplTab3.txt", sep="\t", row.names=FALSE, dec = ".")


##### supplementary table 4
table(annotFile_94$subtype.nCounter, annotFile_94$subtype_genefu_nCounter$subtype_withNormal)


##### supplementary table 5
table(annotFile_94$subtype_genefu_nCounter$subtype_withNormal, annotFile_94$subtype_genefu_RNAseq$subtype_withNormal)


